@@ -801,6 +801,33 @@ class ProvPopTable(pd.DataFrame):
         `ProvPopTableResultsWrapper`.
         '''
 
+        args_in_self = {
+            'pop.sex': self.__pop_sex,
+            'pop.age': self.__pop_age,
+            'pop.end': self.__pop_end,
+            'pop.start': self.__pop_start,
+            'pop.birth': self.__pop_birth,
+            'comp_neg.temp_out': self.__comp_neg_temp_out,
+            'comp_neg.emi': self.__comp_neg_emi,
+            'comp_neg.npr_out': self.__comp_neg_npr_out,
+            'comp_neg.death': self.__comp_neg_death,
+            'comp_neg.interprov_out': self.__comp_neg_interprov_out,
+            'comp_neg.etc': self.__comp_neg_etc,
+            'comp_neg.put_etc_before': self.__comp_neg_put_etc_before,
+            'comp_pos.temp_in': self.__comp_pos_temp_in,
+            'comp_pos.ret_emi': self.__comp_pos_ret_emi,
+            'comp_pos.npr_in': self.__comp_pos_npr_in,
+            'comp_pos.immi': self.__comp_pos_immi,
+            'comp_pos.interprov_in': self.__comp_pos_interprov_in,
+            'comp_pos.etc': self.__comp_pos_etc,
+            'comp_pos.put_etc_before': self.__comp_pos_put_etc_before,
+            'comp.end': self.__comp_end,
+        }
+        prevs = {}
+        for k, v in args_in_self.items():
+            prevs[k] = get_option(k)
+            set_option(k, v)
+
         comp_neg_to_use = self.get_comp_neg()
         comp_pos_to_use = self.get_comp_pos()
         comps = comp_neg_to_use + comp_pos_to_use
@@ -816,26 +843,6 @@ class ProvPopTable(pd.DataFrame):
                 self.copy().loc[lambda df: df[self.__pop_sex] == sex]
             self_cp_sex = ProvPopTable(
                 self_cp_sex,
-                pop_sex = self.__pop_sex,
-                pop_age = self.__pop_age,
-                pop_end = self.__pop_end,
-                pop_start = self.__pop_start,
-                pop_birth = self.__pop_birth,
-                comp_neg_temp_out = self.__comp_neg_temp_out,
-                comp_neg_emi = self.__comp_neg_emi,
-                comp_neg_npr_out = self.__comp_neg_npr_out,
-                comp_neg_death = self.__comp_neg_death,
-                comp_neg_interprov_out = self.__comp_neg_interprov_out,
-                comp_neg_etc = self.__comp_neg_etc,
-                comp_neg_put_etc_before = self.__comp_neg_put_etc_before,
-                comp_pos_temp_in = self.__comp_pos_temp_in,
-                comp_pos_ret_emi = self.__comp_pos_ret_emi,
-                comp_pos_npr_in = self.__comp_pos_npr_in,
-                comp_pos_immi = self.__comp_pos_immi,
-                comp_pos_interprov_in = self.__comp_pos_interprov_in,
-                comp_pos_etc = self.__comp_pos_etc,
-                comp_pos_put_etc_before = self.__comp_pos_put_etc_before,
-                comp_end = self.__comp_end,
                 reorder_cols = False, # since it is reordered already
                 show_pop_end = show_pop_end,
                 # since records are grouped + summarized by 
@@ -866,26 +873,6 @@ class ProvPopTable(pd.DataFrame):
 
                 self_cp_sex = ProvPopTable(
                     self_cp_sex,
-                    pop_sex = self.__pop_sex,
-                    pop_age = self.__pop_age,
-                    pop_end = self.__pop_end,
-                    pop_start = self.__pop_start,
-                    pop_birth = self.__pop_birth,
-                    comp_neg_temp_out = self.__comp_neg_temp_out,
-                    comp_neg_emi = self.__comp_neg_emi,
-                    comp_neg_npr_out = self.__comp_neg_npr_out,
-                    comp_neg_death = self.__comp_neg_death,
-                    comp_neg_interprov_out = self.__comp_neg_interprov_out,
-                    comp_neg_etc = self.__comp_neg_etc,
-                    comp_neg_put_etc_before = self.__comp_neg_put_etc_before,
-                    comp_pos_temp_in = self.__comp_pos_temp_in,
-                    comp_pos_ret_emi = self.__comp_pos_ret_emi,
-                    comp_pos_npr_in = self.__comp_pos_npr_in,
-                    comp_pos_immi = self.__comp_pos_immi,
-                    comp_pos_interprov_in = self.__comp_pos_interprov_in,
-                    comp_pos_etc = self.__comp_pos_etc,
-                    comp_pos_put_etc_before = self.__comp_pos_put_etc_before,
-                    comp_end = self.__comp_end,
                     reorder_cols = False, # since it is reordered already
                     show_pop_end = show_pop_end,
                     # since records are grouped + summarized by 
@@ -924,32 +911,16 @@ class ProvPopTable(pd.DataFrame):
 
         self_copy = ProvPopTable(
             self_copy.sort_values(pop_groups),
-            pop_sex = self.__pop_sex,
-            pop_age = self.__pop_age,
-            pop_end = self.__pop_end,
-            pop_start = self.__pop_start,
-            pop_birth = self.__pop_birth,
-            comp_neg_temp_out = self.__comp_neg_temp_out,
-            comp_neg_emi = self.__comp_neg_emi,
-            comp_neg_npr_out = self.__comp_neg_npr_out,
-            comp_neg_death = self.__comp_neg_death,
-            comp_neg_interprov_out = self.__comp_neg_interprov_out,
-            comp_neg_etc = self.__comp_neg_etc,
-            comp_neg_put_etc_before = self.__comp_neg_put_etc_before,
-            comp_pos_temp_in = self.__comp_pos_temp_in,
-            comp_pos_ret_emi = self.__comp_pos_ret_emi,
-            comp_pos_npr_in = self.__comp_pos_npr_in,
-            comp_pos_immi = self.__comp_pos_immi,
-            comp_pos_interprov_in = self.__comp_pos_interprov_in,
-            comp_pos_etc = self.__comp_pos_etc,
-            comp_pos_put_etc_before = self.__comp_pos_put_etc_before,
-            comp_end = self.__comp_end,
             reorder_cols = False, # since it is reordered already
             show_pop_end = show_pop_end,
             # since records are grouped + summarized by 
             # sex and age already
             flag = False            
         )
+
+        for k2, v2 in prevs.items():
+            set_option(k2, v2)
+
         if return_all_mods:
             if comps_modified == []:
                 return self_copy
