@@ -847,5 +847,7 @@ def run5():
     return poptbl_regions
 
 def run6():
-    pass
-
+    poptbl_regions = run5()
+    poptbl_1001 = poptbl_regions[1001]
+    poptbl_1001_fixed = poptbl_1001.fix_issues(return_all_mods = True)
+    return poptbl_1001_fixed
